#
# spec file for package QCSXCAD
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           QCSXCAD
Version:        0.6.3
Release:        1.6
%define so_ver  0
%define libname lib%{name}%{so_ver}
Summary:        Qt-GUI for CSXCAD library
License:        LGPL-3.0-or-later
Group:          Productivity/Graphics/CAD
URL:            https://openems.de
Source0:        https://github.com/thliebig/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  CSXCAD-devel
BuildRequires:  cmake
BuildRequires:  double-conversion-devel
BuildRequires:  glew-devel
BuildRequires:  lzma-devel
BuildRequires:  tinyxml-devel
BuildRequires:  vtk-devel
BuildRequires:  vtk-qt
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(sm)
BuildRequires:  pkgconfig(xt)

%description
A Qt-GUI for the CSXCAD library.

%package -n     %{libname}
Summary:        Qt-GUI for CSXCAD library
Group:          System/Libraries

%description -n %{libname}
A Qt-GUI for the CSXCAD library.

%package        devel
Summary:        Development files for %{name}
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}

%description    devel
A Qt-GUI for the CSXCAD library.

This package contains libraries and header files for developing
applications that use %{name}.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

%install
%cmake_install

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files -n %{libname}
%license COPYING
%doc NEWS README
%{_libdir}/lib%{name}.so.*

%files devel
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}/

%changelog
* Sun Dec 31 2023 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.6.3
  * Various bug fixes and enhancements, no changelog available.
- Drop obsolete/upstream patches:
  * qt5_use_modules.diff
  * QCSXCAD-no-build-date.patch
  * QCSXCAD-vtk.patch
  * 0001-vtk-use-QVTKOpenGLWidget-for-vtk-8.patch
  * 0001-vtk-fix-changes-for-vtk-8.x.patch
  * 0001-Remove-leftover-QVTKWidget-include-fix-for-VTK-9.patch
  * 0001-Fixup-includes-for-VTK-9.1-compatibility.patch
  * 0001-Add-method-to-get-vtkRenderWindow-from-QVTKStructure.patch
* Fri Nov 25 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add patch to fix compilation with VTK 9.2:
  * 0001-Add-method-to-get-vtkRenderWindow-from-QVTKStructure.patch
* Wed Nov 24 2021 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add patch to fix compilation with VTK 9.1:
  * 0001-Fixup-includes-for-VTK-9.1-compatibility.patch
* Thu Oct 15 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add some patches to fix compilation with VTK 9.x:
  * 0001-vtk-use-QVTKOpenGLWidget-for-vtk-8.patch
  * 0001-vtk-fix-changes-for-vtk-8.x.patch
  * 0001-Remove-leftover-QVTKWidget-include-fix-for-VTK-9.patch
  * Update QCSXCAD-vtk.patch
* Thu Apr  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Add explicit devel BuildRequires for glew, lzma and double-conversion
* Fri Dec 14 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 0.6.2
  * cmake: fix vtk include dirs
  * fix vtk polydata exports
- Add QCSXCAD-vtk.patch - fix build on TW, avoid implicitly requiring
  all VTK modules, leading to missing libraries.
* Mon Jun 18 2018 stefan.bruens@rwth-aachen.de
- Fix build with Qt5.11, cmake qt5_use_modules has been removed.
  Add qt5_use_modules.diff.
- Use Qt5 on all releases, as VTK uses Qt5 everywhere as well.
* Fri Nov 17 2017 stefan.bruens@rwth-aachen.de
- Change the Qt BuildRequires: for older distributions, Leap 42.x
  has a VTK build with Qt4, use the same conditional as the VTK
  package (i.e. Qt4 on Leap 42.x, Qt5 on TW and Leap 15.x)
* Wed Nov  1 2017 stefan.bruens@rwth-aachen.de
- Add explicit BuildRequires for Qt5Sql/Qt5Widgets devel packages,
  as these are no longer implicitly required by vtk-devel
* Fri Aug 26 2016 jengelh@inai.de
- Update description, and license field to LGPL-3.0+.
* Fri Aug 26 2016 dmitry_r@opensuse.org
- Update to version 0.6.1
  * Bugfix release
- Drop obsolete
  * QCSXCAD-vtk.patch
  * QCSXCAD-vtk7-support.patch
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Fix build with VTK 7
  * QCSXCAD-vtk7-support.patch
* Sun Nov  8 2015 dmitry_r@opensuse.org
- Initial package, version 0.6.0
- Remove build time from binaries
  * QCSXCAD-no-build-date.patch
- Fix build with VTK 6.3
  * QCSXCAD-vtk.patch
